@@ -1,183 +1,19 @@
 #include <gnome.h>
 
+/* ---------------------------------------------------------------------- */
+
 #include "waterfall.h"
-#include "scope.h"
+#include "miniscope.h"
+#include "gtkdial.h"
+#include "papertape.h"
 
 /* ---------------------------------------------------------------------- */
 
-/*
- * These are actually in syncscope.c
- */
-
-gboolean
-on_syncscope_darea_configure_event       (GtkWidget       *widget,
-                                          GdkEventConfigure *event,
-                                          gpointer         user_data);
-
-gboolean
-on_syncscope_darea_expose_event          (GtkWidget       *widget,
-                                          GdkEventExpose  *event,
-                                          gpointer         user_data);
-
-gboolean
-on_syncscope_darea_button_press_event    (GtkWidget       *widget,
-                                          GdkEventButton  *event,
-                                          gpointer         user_data);
-
-/* ---------------------------------------------------------------------- */
-
-void
-on_exit1_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_preferences1_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_about1_activate                     (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-gboolean
-on_waterfall_motion_notify_event       (GtkWidget       *widget,
-                                        GdkEventMotion  *event,
-                                        gpointer         user_data);
-
-gboolean
-on_waterfall_button_press_event        (GtkWidget       *widget,
-                                        GdkEventButton  *event,
-                                        gpointer         user_data);
-
-void
-on_freqspinbutton_changed              (GtkEditable     *editable,
-                                        gpointer         user_data);
-
 gboolean
 on_appwindow_delete_event              (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data);
 
-void
-on_afcbutton_toggled                   (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-gboolean
-on_waterfall_leave_notify_event        (GtkWidget       *widget,
-                                        GdkEventCrossing *event,
-                                        gpointer         user_data);
-
-void
-on_macrobutton_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
-
-gboolean
-on_macrobutton_button_press_event      (GtkWidget       *widget,
-                                        GdkEventButton  *event,
-                                        gpointer         user_data);
-
-void
-on_macroconfigclear_clicked            (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_macroconfigok_clicked               (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_macroconfigcancel_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_propertybox_apply                   (GnomePropertyBox *gnomepropertybox,
-                                        gint             arg1,
-                                        gpointer         user_data);
-
-void
-on_pausebutton_toggled                 (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_rxbutton_toggled                    (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_txbutton_toggled                    (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_abortbutton_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_squelchbutton_toggled               (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-gboolean
-on_rxtext_button_press_event           (GtkWidget       *widget,
-                                        GdkEventButton  *event,
-                                        gpointer         user_data);
-
-void
-on_callsign1_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_qth1_activate                       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-gboolean
-on_txtext_key_press_event              (GtkWidget       *widget,
-                                        GdkEventKey     *event,
-                                        gpointer         user_data);
-
-void
-on_logbutton_clicked                   (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_newbutton_clicked                   (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_name1_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_received_rst1_activate              (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_sent_rst1_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_notes1_activate                     (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_band1_activate                      (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_qsoentry_changed                    (GtkEditable     *editable,
-                                        gpointer         user_data);
-
-gboolean
-on_macroconfigwindow_delete_event      (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-gboolean
-on_txtext_button_press_event           (GtkWidget       *widget,
-                                        GdkEventButton  *event,
-                                        gpointer         user_data);
-
-void
-on_txtext_selection_received           (GtkWidget       *widget,
-                                        GtkSelectionData *data,
-                                        guint            time,
-                                        gpointer         user_data);
-
 void
 on_send_file1_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -186,10 +22,6 @@ void
 on_log_to_file1_activate               (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_stop_logging1_activate              (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_clear_tx_window1_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -198,6 +30,50 @@ void
 on_clear_rx_window1_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_exit1_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_mfsk1_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_mfsk2_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_rtty1_activate                      (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_throb1_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_throb2_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_throb4_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_bpsk31_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_qpsk31_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_feldhell1_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_preferences1_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
 void
 on_macroconfig1_activate               (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -246,6 +122,85 @@ void
 on_macroconfig12_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_about1_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_pausebutton_toggled                 (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_rxbutton_toggled                    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_txbutton_toggled                    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_abortbutton_clicked                 (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_tunebutton_toggled                  (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_qsoentry_changed                    (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_logbutton_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_newbutton_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_rxtext_button_press_event           (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_txtext_key_press_event              (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data);
+
+gboolean
+on_txtext_button_press_event           (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_txtext_selection_received           (GtkWidget       *widget,
+                                        GtkSelectionData *data,
+                                        guint            time,
+                                        gpointer         user_data);
+
+gboolean
+on_waterfall_button_press_event        (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_freqspinbutton_changed              (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_afcbutton_toggled                   (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_squelchbutton_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_reversebutton_toggled               (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+
 gboolean
 on_txfileselection_delete_event        (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -259,59 +214,186 @@ void
 on_txfileselect_cancel_button_clicked  (GtkButton       *button,
                                         gpointer         user_data);
 
+void
+on_wfpause_activate                    (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfmode_normal_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfmode_spectrum_activate            (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfmode_scope_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfmag_1_activate                    (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfmag_2_activate                    (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfmag_4_activate                    (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfwindow_rect_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfwindow_tria_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfwindow_hamm_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+
+void
+on_macrobutton1_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
 gboolean
-on_rxfileselection_delete_event        (GtkWidget       *widget,
-                                        GdkEvent        *event,
+on_macrobutton1_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_rxfileselect_ok_button_clicked      (GtkButton       *button,
+on_macrobutton2_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton2_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_rxfileselect_cancel_button_clicked  (GtkButton       *button,
+on_macrobutton3_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton3_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_tunebutton_toggled                  (GtkToggleButton *togglebutton,
+on_macrobutton4_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton4_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_mfsk1_activate                      (GtkMenuItem     *menuitem,
+on_macrobutton5_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton5_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_rtty1_activate                      (GtkMenuItem     *menuitem,
+on_macrobutton6_clicked                (GtkButton       *button,
                                         gpointer         user_data);
 
-
-void
-on_throb1_activate                     (GtkMenuItem     *menuitem,
+gboolean
+on_macrobutton6_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_throb2_activate                     (GtkMenuItem     *menuitem,
+on_macrobutton7_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton7_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_throb4_activate                     (GtkMenuItem     *menuitem,
+on_macrobutton8_clicked                (GtkButton       *button,
                                         gpointer         user_data);
 
-
-void
-on_reversebutton_toggled               (GtkToggleButton *togglebutton,
+gboolean
+on_macrobutton8_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_mag1button_toggled                  (GtkToggleButton *togglebutton,
+on_macrobutton9_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton9_button_press_event     (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_mag2button_toggled                  (GtkToggleButton *togglebutton,
+on_macrobutton10_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton10_button_press_event    (GtkWidget       *widget,
+                                        GdkEventButton  *event,
                                         gpointer         user_data);
 
 void
-on_mag4button_toggled                  (GtkToggleButton *togglebutton,
+on_macrobutton11_clicked               (GtkButton       *button,
                                         gpointer         user_data);
 
+gboolean
+on_macrobutton11_button_press_event    (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
 
+void
+on_macrobutton12_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_macrobutton12_button_press_event    (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_rxtext_populate_popup               (GtkTextView     *textview,
+                                        GtkMenu         *menu,
+                                        gpointer         user_data);
+
+void
+on_txtext_populate_popup               (GtkTextView     *textview,
+                                        GtkMenu         *menu,
+                                        gpointer         user_data);
+
+void
+on_mt63_activate                       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_confrestartbutton_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_rxtext_button_press_event           (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_wfspeed_half_activate               (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfspeed_normal_activate             (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_wfspeed_double_activate             (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
