@@ -14,73 +14,32 @@ extern void send_macro(gint n);
 
 /* ---------------------------------------------------------------------- */
 
-#define MACRODEF1NAME	"CQ"
-#define	MACRODEF1TEXT	"\
-$tx\n\
-cq cq cq de $mycall $mycall $mycall\n\
-cq cq cq de $mycall $mycall $mycall\n\
-cq cq cq de $mycall $mycall $mycall\n\
-\n\
-($utcdate $utctime)\n\
-\n\
-pse k\n\
-$rx"
+#define MACRODEF1NAME	""
+#define	MACRODEF1TEXT	""
 
 /* ---------------------------------------------------------------------- */
 
-#define MACRODEF2NAME	"Station"
-#define MACRODEF2TEXT	"\
----\n\
-$mycall station info:\n\
-\n\
-Name:   $myname\n\
-QTH:    $myqth, Locator: $myloc\n\
-Email:  $myemail\n\
-Rig:    Icom IC-745\n\
-Pwr:    abt 20 W\n\
-Ant:    end fed wire + SG-237 automatic ATU\n\
-Comp:   Pentium 200 MHz 64 MB\n\
-OS:     RedHat Linux 6.2\n\
-Soft:   $soft\n\
-\n\
-localtime: $time ($utctime)\n\
-\n\
----\n\
-"
+#define MACRODEF2NAME	""
+#define MACRODEF2TEXT	""
 
 /* ---------------------------------------------------------------------- */
 
-#define MACRODEF3NAME	"BTU"
-#define MACRODEF3TEXT	"\
-btu $call de $mycall k\n\
-$rx"
-
-#define MACRODEF4NAME	"call de mycall"
-#define MACRODEF4TEXT   "\
-$tx\n\
-$call de $mycall\n\
-"
+#define MACRODEF3NAME	""
+#define MACRODEF3TEXT	""
 
 /* ---------------------------------------------------------------------- */
 
-#define MACRODEF5NAME	"QRZ ?"
-#define MACRODEF5TEXT	"\
-$tx\n\
-qrz? qrz? qrz? de $mycall $mycall $mycall\n\
-\n\
-pse kn\n\
-$rx"
+#define MACRODEF4NAME	""
+#define MACRODEF4TEXT	""
+
+/* ---------------------------------------------------------------------- */
+#define MACRODEF5NAME	""
+#define MACRODEF5TEXT	""
 
 /* ---------------------------------------------------------------------- */
 
-#define MACRODEF6NAME	"73 & sk"
-#define MACRODEF6TEXT	"\
-Thanks for very nice MFSK QSO dr $name.\n\
-QSL is ok via buro if needed.\n\
-73 and hope to see you soon again on MFSK, my favorite digital mode.\n\
-$call de $mycall\n\
-sk sk\n\
-$rx "
+#define MACRODEF6NAME	""
+#define MACRODEF6TEXT	""
 
 /* ---------------------------------------------------------------------- */
 
