@@ -3,19 +3,21 @@
 
 #include "cmplx.h"
 #include "trx.h"
+#include "viterbi.h"
+#include "interleave.h"
 
 #define	SampleRate	8000
-#define	SymbolLen	512
-#define	BaseTone	64
-#define	NumTones	16
-#define	SymbolRate	((float)SampleRate/SymbolLen)
-#define	ToneSpacing	SymbolRate
 
-#define	TxQueueSize	64
-#define	PipeLen		(2*SymbolLen)
+//#define	SymbolLen	512
+//#define	BaseTone	64
+//#define	NumTones	16
+//#define	SymbolRate	((float)SampleRate/SymbolLen)
+//#define	ToneSpacing	SymbolRate
+
+//#define	PipeLen		(2*SymbolLen)
 
 struct rxpipe {
-	complex vector[NumTones];
+	complex vector[32];	/* numtones <= 32 */
 	int symbol;
 };
 
@@ -23,16 +25,26 @@ struct mfsk {
 	/*
 	 * Common stuff
 	 */
-	float phaseacc;
+	double phaseacc;
+
+	int symlen;
+	int symbits;
+	int numtones;
+	int basetone;
+	double tonespacing;
 
 	/*
 	 * RX related stuff
 	 */
 	struct filter *hilbert;
 	struct sfft *sfft;
-	struct viterbi *viterbi;
+	struct viterbi_old *viterbi;
 
-	struct rxpipe pipe[PipeLen];
+	struct viterbi *dec1;
+	struct viterbi *dec2;
+	struct interleave *rxinlv;
+
+	struct rxpipe *pipe;
 	unsigned int pipeptr;
 
 	unsigned int datashreg;
@@ -45,20 +57,25 @@ struct mfsk {
 	int prev1symbol;
 	int prev2symbol;
 
-	long int prevmetric;
-	float averagemetric;
+	float metric1;
+	float metric2;
 
 	unsigned int symbolphase;
 	unsigned int symboltime;
 	float syncaverage;
 	int synccounter;
 
+	unsigned char symbolpair[2];
+	int symcounter;
+
 	/*
 	 * TX related stuff
 	 */
 	struct fft *fft;
 
-	unsigned int encstate;
+	struct encoder *enc;
+	struct interleave *txinlv;
+
 	unsigned int bitshreg;
 	int bitstate;
 	int txstate;
