@@ -23,10 +23,10 @@ struct fftfilt {
 
 /* ---------------------------------------------------------------------- */
 
-extern struct fftfilt *init_fftfilt(double f1, double f2, int len);
-extern void clear_fftfilt(struct fftfilt *s);
+extern struct fftfilt *fftfilt_init(double f1, double f2, int len);
+extern void fftfilt_free(struct fftfilt *s);
 
-extern int fftfilt(struct fftfilt *, complex in, complex **out);
+extern int fftfilt_run(struct fftfilt *, complex in, complex **out);
 
 /* ---------------------------------------------------------------------- */
 
