@@ -3,7 +3,6 @@
 
 #include "cmplx.h"
 
-#define FilterLen	37
 #define BufferLen	1024
 
 /* ---------------------------------------------------------------------- */
@@ -15,12 +14,12 @@
 /* ---------------------------------------------------------------------- */
 
 #ifndef __HAVE_ARCH_MAC
-extern __inline__ float mac(const float *a, const float *b)
+extern __inline__ float mac(const float *a, const float *b, unsigned int size)
 {
 	float sum = 0;
 	unsigned int i;
 
-	for (i = 0; i < FilterLen; i++)
+	for (i = 0; i < size; i++)
 		sum += (*a++) * (*b++);
 	return sum;
 }
@@ -29,19 +28,26 @@ extern __inline__ float mac(const float *a, const float *b)
 /* ---------------------------------------------------------------------- */
 
 struct filter {
-	float ifilter[FilterLen];
-	float qfilter[FilterLen];
+	int length;
+	int decimateratio;
+
+	float *ifilter;
+	float *qfilter;
+
 	float ibuffer[BufferLen];
 	float qbuffer[BufferLen];
-	int ptr;
+
+	int pointer;
+	int counter;
 };
 
-extern struct filter *init_filter(float, float);
-extern void clear_filter(struct filter *);
+extern struct filter *filter_init(int len, int dec, float *ifil, float *qfil);
+extern struct filter *filter_init_hilbert(int len);
+extern void filter_free(struct filter *f);
 
-extern complex filter(struct filter *, complex);
-extern float filterI(struct filter *, float);
-extern float filterQ(struct filter *, float);
+extern int filter_run(struct filter *f, complex in, complex *out);
+extern int filter_I_run(struct filter *f, float in, float *out);
+extern int filter_Q_run(struct filter *f, float in, float *out);
 
 /* ---------------------------------------------------------------------- */
 #endif				/* _FILTER_H */
