@@ -14,9 +14,9 @@ struct sfft {
 	double corr;
 };
 
-extern struct sfft *init_sfft(int, int, int);
-extern void clear_sfft(struct sfft *);
+extern struct sfft *sfft_init(int, int, int);
+extern void sfft_free(struct sfft *);
 
-extern complex *sfft(struct sfft *, complex);
+extern complex *sfft_run(struct sfft *, complex);
 
 #endif
