@@ -11,9 +11,13 @@
 
 static int pttfd = -1;
 static int pttinv = 0;
+static int pttarg = TIOCM_RTS | TIOCM_DTR;
 
-void init_ptt(char *path, int inverted)
+void init_ptt(const char *path, int inverted, int mode)
 {
+	// fprintf(stderr, "init_ptt(path=%s, inv=%d, mode=%d\n",
+	//	path, inverted, mode);
+
 	if (pttfd != -1) {
 		set_ptt(0);
 		close(pttfd);
@@ -22,6 +26,18 @@ void init_ptt(char *path, int inverted)
 
 	pttinv = inverted;
 
+	switch (mode) {
+	case 0:
+		pttarg = TIOCM_RTS;
+		break;
+	case 1:
+		pttarg = TIOCM_DTR;
+		break;
+	case 2:
+		pttarg = TIOCM_RTS | TIOCM_DTR;
+		break;
+	}
+
 	if (!strcasecmp(path, "none"))
 		return;
 
@@ -36,7 +52,7 @@ void init_ptt(char *path, int inverted)
 
 void set_ptt(int ptt)
 {
-	int arg = TIOCM_RTS | TIOCM_DTR;
+	int arg = pttarg;
 
 	if (pttfd == -1)
 		return;
