@@ -1,7 +1,7 @@
 #ifndef _PTT_H
 #define _PTT_H
 
-extern void init_ptt(char *path, int inverted);
+extern void init_ptt(const char *path, int inverted, int mode);
 extern void set_ptt(int ptt);
 
 #endif
