@@ -1,6 +1,10 @@
 #ifndef _SND_H
 #define _SND_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern int sound_open_for_write(int srate);
 extern int sound_open_for_read(int srate);
 
@@ -11,4 +15,8 @@ extern int sound_read(float *buf, int count);
 
 extern char *sound_error(void);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
